@@ -9,6 +9,7 @@ import socket
 import string
 import sys
 import time
+import json
 from contextlib import closing
 from copy import copy
 
@@ -20,7 +21,9 @@ from six.moves import range
 import koji
 # import parse_arches to current namespace for backward compatibility
 from koji import parse_arches
+from koji import _  # noqa: F401
 from koji.util import md5_constructor, to_list
+from koji.xmlrpcplus import xmlrpc_client
 
 
 # for compatibility with plugins based on older version of lib
@@ -41,8 +44,7 @@ def _check_time_option(option, opt, value):
         ts = time.mktime(dt.timetuple())
         return ts
     except Exception:
-        raise optparse.OptionValueError(
-            _("option %s: invalid time specification: %r") % (opt, value))
+        raise optparse.OptionValueError("option %s: invalid time specification: %r" % (opt, value))
 
 
 class TimeOption(optparse.Option):
@@ -53,9 +55,8 @@ class TimeOption(optparse.Option):
 
     @classmethod
     def get_help(self):
-        return _("time is specified as timestamp or date/time in any "
-                 "format which can be parsed by dateutil.parser. e.g. "
-                 "\"2020-12-31 12:35\" or \"December 31st 12:35\"")
+        return "time is specified as timestamp or date/time in any format which can be " \
+               "parsed by dateutil.parser. e.g. \"2020-12-31 12:35\" or \"December 31st 12:35\""
 
 
 greetings = ('hello', 'hi', 'yo', "what's up", "g'day", 'back to work',
@@ -85,11 +86,6 @@ ARGMAP = {'None': None,
           'False': False}
 
 
-def _(args):
-    """Stub function for translation"""
-    return args
-
-
 def arg_filter(arg):
     try:
         return int(arg)
@@ -128,25 +124,29 @@ Try "%(progname)s <command> --help" for help about the options of a particular c
 Try "%(progname)s help <category>" to get commands under a particular category
 Available categories are: %(categories)s
 ''' % ({'progname': progname, 'categories': categories_ordered})
-    return _(epilog_str)
+    return epilog_str
 
 
 def get_usage_str(usage):
-    return usage + _("\n(Specify the --help global option for a list of other help options)")
+    return usage + "\n(Specify the --help global option for a list of other help options)"
 
 
 def ensure_connection(session, options=None):
+    if options and options.force_auth:
+        # in such case we should act as a real activate_session
+        activate_session(session, options)
+        return
     try:
         ret = session.getAPIVersion()
     except requests.exceptions.ConnectionError as ex:
-        warn(_("Error: Unable to connect to server"))
+        warn("Error: Unable to connect to server")
         if options and getattr(options, 'debug', False):
             error(str(ex))
         else:
             error()
     if ret != koji.API_VERSION:
-        warn(_("WARNING: The server is at API version %d and "
-               "the client is at %d" % (ret, koji.API_VERSION)))
+        warn("WARNING: The server is at API version %d and "
+             "the client is at %d" % (ret, koji.API_VERSION))
 
 
 def print_task_headers():
@@ -559,9 +559,9 @@ def download_file(url, relpath, quiet=False, noprogress=False, size=None,
         koji.ensuredir(os.path.dirname(relpath))
     if not quiet:
         if size and num:
-            print(_("Downloading [%d/%d]: %s") % (num, size, relpath))
+            print("Downloading [%d/%d]: %s" % (num, size, relpath))
         else:
-            print(_("Downloading: %s") % relpath)
+            print("Downloading: %s" % relpath)
 
     pos = 0
     headers = {}
@@ -572,10 +572,10 @@ def download_file(url, relpath, quiet=False, noprogress=False, size=None,
         if pos:
             if filesize == pos:
                 if not quiet:
-                    print(_("File %s already downloaded, skipping" % relpath))
+                    print("File %s already downloaded, skipping" % relpath)
                 return
             if not quiet:
-                print(_("Appending to existing file %s" % relpath))
+                print("Appending to existing file %s" % relpath)
             headers['Range'] = ('bytes=%d-' % pos)
     else:
         # rewrite
@@ -674,7 +674,7 @@ def download_archive(build, archive, topurl, quiet=False, noprogress=False):
     if archive['checksum_type'] == koji.CHECKSUM_TYPES['md5']:
         hash = md5_constructor()
     elif archive['checksum_type'] == koji.CHECKSUM_TYPES['sha1']:
-        hash = hashlib.sha1()
+        hash = hashlib.sha1()  # nosec
     elif archive['checksum_type'] == koji.CHECKSUM_TYPES['sha256']:
         hash = hashlib.sha256()
     else:
@@ -748,9 +748,11 @@ def activate_session(session, options):
             else:
                 session.gssapi_login(proxyuser=runas)
         except socket.error as e:
-            warn(_("Could not connect to Kerberos authentication service: %s") % e.args[1])
+            warn("Could not connect to Kerberos authentication service: %s" % e.args[1])
     if not noauth and not session.logged_in:
-        error(_("Unable to log in, no authentication methods available"))
+        error("Unable to log in, no authentication methods available")
+    # don't add "options" to ensure_connection it would create loop in case of --force-auth
+    # when it calls activate_session
     ensure_connection(session)
     if getattr(options, 'debug', None):
         print("successfully connected to hub")
@@ -830,3 +832,22 @@ def format_inheritance_flags(parent):
         else:
             flags += '.'
     return flags
+
+
+def truncate_string(s, length=47):
+    """Return a truncated string when string length is longer than given length."""
+    if s:
+        s = s.replace('\n', ' ')
+        if len(s) > length:
+            return s[:length] + '...'
+        else:
+            return s
+    else:
+        return ''
+
+
+class DatetimeJSONEncoder(json.JSONEncoder):
+    def default(self, o):
+        if isinstance(o, xmlrpc_client.DateTime):
+            return str(o)
+        return json.JSONEncoder.default(self, o)
