@@ -10,32 +10,22 @@ from argparse import ArgumentParser
 import koji
 from koji.plugin import export_cli
 from koji_cli.commands import anon_handle_wait_repo
-from koji_cli.lib import _, activate_session, arg_filter
+from koji_cli.lib import activate_session, arg_filter
 
 
 @export_cli
 def handle_add_sidetag(options, session, args):
     "Create sidetag"
-    usage = _("%(prog)s add-sidetag [options] <basetag>")
-    usage += _("\n(Specify the --help global option for a list of other help options)")
+    usage = "%(prog)s add-sidetag [options] <basetag>"
+    usage += "\n(Specify the --help global option for a list of other help options)"
     parser = ArgumentParser(usage=usage)
     parser.add_argument("basetag", help="name of basetag")
-    parser.add_argument(
-        "-q",
-        "--quiet",
-        action="store_true",
-        help=_("Do not print tag name"),
-        default=options.quiet,
-    )
-    parser.add_argument(
-        "-w", "--wait", action="store_true", help=_("Wait until repo is ready.")
-    )
-    parser.add_argument(
-        "--debuginfo", action="store_true", help=_("Buildroot repo will contain debuginfos")
-    )
-    parser.add_argument(
-        "--suffix", action="store", help=_("Suffix from hub-supported ones")
-    )
+    parser.add_argument("-q", "--quiet", action="store_true", help="Do not print tag name",
+                        default=options.quiet)
+    parser.add_argument("-w", "--wait", action="store_true", help="Wait until repo is ready.")
+    parser.add_argument("--debuginfo", action="store_true",
+                        help="Buildroot repo will contain debuginfos")
+    parser.add_argument("--suffix", action="store", help="Suffix from hub-supported ones")
 
     opts = parser.parse_args(args)
 
@@ -47,10 +37,10 @@ def handle_add_sidetag(options, session, args):
     try:
         tag = session.createSideTag(opts.basetag, **kwargs)
     except koji.ActionNotAllowed:
-        parser.error(_("Policy violation"))
+        parser.error("Policy violation")
     except koji.ParameterError as ex:
         if 'suffix' in str(ex):
-            parser.error(_("Hub is older and doesn't support --suffix, please run it without it"))
+            parser.error("Hub is older and doesn't support --suffix, please run it without it")
         else:
             raise
 
@@ -67,8 +57,8 @@ def handle_add_sidetag(options, session, args):
 @export_cli
 def handle_remove_sidetag(options, session, args):
     "Remove sidetag"
-    usage = _("%(prog)s remove-sidetag [options] <sidetag> ...")
-    usage += _("\n(Specify the --help global option for a list of other help options)")
+    usage = "%(prog)s remove-sidetag [options] <sidetag> ..."
+    usage += "\n(Specify the --help global option for a list of other help options)"
     parser = ArgumentParser(usage=usage)
     parser.add_argument("sidetags", help="name of sidetag", nargs="+")
     opts = parser.parse_args(args)
@@ -84,17 +74,17 @@ def handle_remove_sidetag(options, session, args):
 @export_cli
 def handle_list_sidetags(options, session, args):
     "List sidetags"
-    usage = _("%(prog)s list-sidetags [options]")
-    usage += _("\n(Specify the --help global option for a list of other help options)")
+    usage = "%(prog)s list-sidetags [options]"
+    usage += "\n(Specify the --help global option for a list of other help options)"
     parser = ArgumentParser(usage=usage)
-    parser.add_argument("--basetag", action="store", help=_("Filter on basetag"))
-    parser.add_argument("--user", action="store", help=_("Filter on user"))
-    parser.add_argument("--mine", action="store_true", help=_("Filter on user"))
+    parser.add_argument("--basetag", action="store", help="Filter on basetag")
+    parser.add_argument("--user", action="store", help="Filter on user")
+    parser.add_argument("--mine", action="store_true", help="Filter on user")
 
     opts = parser.parse_args(args)
 
     if opts.mine and opts.user:
-        parser.error(_("Specify only one from --user --mine"))
+        parser.error("Specify only one from --user --mine")
 
     if opts.mine:
         activate_session(session, options)
@@ -109,17 +99,17 @@ def handle_list_sidetags(options, session, args):
 @export_cli
 def handle_edit_sidetag(options, session, args):
     "Edit sidetag"
-    usage = _("%(prog)s edit-sidetag [options]")
-    usage += _("\n(Specify the --help global option for a list of other help options)")
+    usage = "%(prog)s edit-sidetag [options]"
+    usage += "\n(Specify the --help global option for a list of other help options)"
     parser = ArgumentParser(usage=usage)
     parser.add_argument("sidetag", help="name of sidetag")
     parser.add_argument("--debuginfo", action="store_true", default=None,
-                        help=_("Generate debuginfo repository"))
+                        help="Generate debuginfo repository")
     parser.add_argument("--no-debuginfo", action="store_false", dest="debuginfo")
     parser.add_argument("--rpm-macro", action="append", default=[], metavar="key=value",
-                        dest="rpm_macros", help=_("Set tag-specific rpm macros"))
+                        dest="rpm_macros", help="Set tag-specific rpm macros")
     parser.add_argument("--remove-rpm-macro", action="append", default=[], metavar="key",
-                        dest="remove_rpm_macros", help=_("Remove rpm macros"))
+                        dest="remove_rpm_macros", help="Remove rpm macros")
 
     opts = parser.parse_args(args)
 
